pyxmpp2.sasl

Package pyxmpp2 :: Package sasl |
[hide private]

# Package sasl

SASL authentication implementaion for PyXMPP.

Normative reference:
  - RFC 4422

Submodules | [hide private]
pyxmpp2.sasl.core: Base classes for PyXMPP SASL implementation. pyxmpp2.sasl.digest_md5: DIGEST-MD5 authentication mechanism for PyXMPP SASL implementation. pyxmpp2.sasl.external: External SASL authentication mechanism for PyXMPP SASL implementation. pyxmpp2.sasl.gssapi: GSSAPI authentication mechanism for PyXMPP SASL implementation. pyxmpp2.sasl.plain: PLAIN authentication mechanism for PyXMPP SASL implementation.

Functions | [hide private]
sasl.core.ClientAuthenticator |
client_authenticator_factory(mechanism, password_manager) Create a client authenticator object for given SASL mechanism and password manager. |
sasl.core.ServerAuthenticator |
server_authenticator_factory(mechanism, password_manager) Create a server authenticator object for given SASL mechanism and password manager. |

Function Details | [hide private]

### client_authenticator_factory(mechanism, password_manager) |
Create a client authenticator object for given SASL mechanism and password manager. Parameters: `mechanism` (`unicode`) - name of the SASL mechanism ("PLAIN", "DIGEST-MD5" or "GSSAPI"). `password_manager` (PasswordManager) - name of the password manager object providing authentication credentials. Returns: sasl.core.ClientAuthenticator new authenticator. Raises: `KeyError` - if no client authenticator is available for this mechanism

### server_authenticator_factory(mechanism, password_manager) |
Create a server authenticator object for given SASL mechanism and password manager. Parameters: `mechanism` (`str`) - name of the SASL mechanism ("PLAIN", "DIGEST-MD5" or "GSSAPI"). `password_manager` (PasswordManager) - name of the password manager object to be used for authentication credentials verification. Returns: sasl.core.ServerAuthenticator new authenticator. Raises: `KeyError` - if no server authenticator is available for this mechanism